pub enum PackageSource {
Path(PathBuf),
Git {
url: Url,
git_ref: GitReference,
},
RemoteRegistry(Url),
LocalRegistry(PathBuf),
CratesIo,
}Expand description
Defines a source from which a package can be fetched.
This enum can either be constructed manually, or with associated helper functions on it.
Variants
Path(PathBuf)
Path source:
dep = { path = "some/local/dependency" }Git
Git source:
regex = { git = "https://github.com/rust-lang/regex", branch = "next" }RemoteRegistry(Url)
Remote registry:
some-crate = { version = "1.0", registry = "my-registry" }LocalRegistry(PathBuf)
Local registry:
some-crate = { version = "1.0", registry = "my-local-registry" }CratesIo
crates.io:
foo = "1.0.0"Note that this does not respect .cargo/config.toml, so if default-registry or crates-io
are overriden, this would still fetch from crates.io
Implementations
Sourceimpl PackageSource
impl PackageSource
Sourcepub fn path<P: Into<PathBuf>>(path: P) -> Result<Self, String>
pub fn path<P: Into<PathBuf>>(path: P) -> Result<Self, String>
Constructs a new PackageSource::Path from path.
Sourcepub fn git<U: AsRef<str>>(
url: U,
git_ref: Option<GitReference>,
) -> Result<Self, <Url as FromStr>::Err>
pub fn git<U: AsRef<str>>( url: U, git_ref: Option<GitReference>, ) -> Result<Self, <Url as FromStr>::Err>
Constructs a new PackageSource::Git from repository url and an optional GitReference, if None is provided, GitReference::DefaultBranch will be assumed.
Sourcepub fn remote<U: TryInto<Url>>(url: U) -> Result<Self, U::Error>
pub fn remote<U: TryInto<Url>>(url: U) -> Result<Self, U::Error>
Constructs a new PackageSource::RemoteRegistry from a registry index url.
Sourcepub fn local<P: Into<PathBuf>>(path: P) -> Self
pub fn local<P: Into<PathBuf>>(path: P) -> Self
Constructs a new PackageSource::LocalRegistry from a registry index path.
Sourcepub fn crates_io() -> Self
pub fn crates_io() -> Self
Returns PackageSource::CratesIo.